@@ -1,10 +1,8 @@
-/* $Cambridge: exim/exim-src/src/transports/pipe.h,v 1.6 2007/01/08 10:50:20 ph10 Exp $ */
-
 /*************************************************
 *     Exim - an Internet mail transport agent    *
 *************************************************/
 
-/* Copyright (c) University of Cambridge 1995 - 2007 */
+/* Copyright (c) University of Cambridge 1995 - 2009 */
 /* See the file NOTICE for conditions of use and distribution. */
 
 /* Private structure for the private options. */
@@ -24,7 +22,9 @@ typedef struct {
   int   timeout;
   int   options;
   BOOL  freeze_exec_fail;
+  BOOL  freeze_signal;
   BOOL  ignore_status;
+  BOOL  permit_coredump;
   BOOL  restrict_to_path;
   BOOL  timeout_defer;
   BOOL  use_shell;
